#
# This is the SPEC file for creating binary RPMs for the Dom0.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2010  Joanna Rutkowska <joanna@invisiblethingslab.com>
# Copyright (C) 2010  Rafal Wojtczuk  <rafal@invisiblethingslab.com>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, see <https://www.gnu.org/licenses/>.
#
#

Name:		qubes-core-qrexec-vm
Version:	4.1.7
Release:	1%{dist}
Summary:	The Qubes qrexec files (qube side)

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org

BuildRequires:	gcc
BuildRequires:	pam-devel
BuildRequires:	pandoc
BuildRequires:	qubes-libvchan-devel
BuildRequires:	qubes-core-qrexec-devel
BuildRequires:	lsb-core-noarch
BuildRequires:	systemd-devel

Requires:   python%{python3_pkgversion}
Requires:   qubes-core-qrexec = %{version}-%{release}

Provides:   qubes-core-agent-qrexec = 4.1.0-1
Obsoletes:  qubes-core-agent-qrexec < 4.1.0-1

Source0: qubes-core-qrexec-%{version}.tar.gz

%description
The Qubes qrexec files for installation on a qube.

%prep
%setup -qn qubes-core-qrexec-%{version}

%build
%{?set_build_flags}
export BACKEND_VMM=xen
make all-vm
#make -C doc PYTHON=%{__python3} SPHINXBUILD=sphinx-build-%{python3_version} man

%install
make install-vm \
    DESTDIR=$RPM_BUILD_ROOT \
    UNITDIR=%{_unitdir} \
    PYTHON_SITEPATH=%{python3_sitelib} \
    SYSCONFDIR=%{_sysconfdir}

#make -C doc DESTDIR=$RPM_BUILD_ROOT \
#    PYTHON=%{__python3} SPHINXBUILD=sphinx-build-%{python3_version} \
#    install

%clean
rm -rf $RPM_BUILD_ROOT
rm -f %{name}-%{version}

%post
%systemd_post qubes-qrexec-agent.service

%preun
%systemd_preun qubes-qrexec-agent.service

%posttrans
# when upgrading from R4.0, %%postun of qubes-core-agent-qrexec will revert
# %%post of this package. Redo the action in %%posttrans
%systemd_post qubes-qrexec-agent.service
# and then start it back
if systemctl is-enabled qubes-qrexec-agent.service >/dev/null 2>&1; then
    systemctl start qubes-qrexec-agent.service
fi

%files
%defattr(-,root,root,-)
%config(noreplace) /etc/pam.d/qrexec
%dir /etc/qubes/rpc-config
/etc/qubes/rpc-config/README

%{_bindir}/qrexec-client-vm
%{_bindir}/qrexec-fork-server

%{_mandir}/man1/qrexec-client-vm.1*

/usr/lib/qubes/qrexec-agent
/usr/lib/qubes/qrexec-client-vm
/usr/lib/qubes/qrexec_client_vm
/lib/systemd/system/qubes-qrexec-agent.service

%changelog
* Sat Apr 04 2020 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-core-qrexec

* Sat Apr 04 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4fa17c9
- version 4.1.7

* Wed Apr 01 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - a24a446
- spec: fix hardcoded python3 prefix for CentOS

* Tue Mar 31 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 4dc330b
- Remove false error message on vchan disconnect

* Tue Mar 31 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8ffe427
- Adjust dependencies to avoid breaking USB proxy

* Mon Mar 30 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 323c19b
- fuzzer: use C++ compiler for linking

* Mon Mar 30 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 817f9f0
- policy/utils: fix pyinotify cleanup

* Sat Mar 28 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 5fdd524
- qrexec-agent, qrexec-daemon: unblock signals before exec()

* Sat Mar 28 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - c9b3439
- qrexec-client: handle failed service exec

* Sat Mar 28 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 97373fa
- version 4.1.6

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 7f6d27b
- travis: add job names, add fuzzer

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - c7ce579
- qrexec-policy-agent: always show service argument

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 868b265
- policy-agent: use autostart program, not systemd service

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 1206fe3
- Support wait-for-session in dom0

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - f952240
- Factor out parsing service configuration

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 2c1e737
- Add a requirement for qubes-core-dom0 version >= 4.1.9

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 64935af
- Clean up call() and call_async()

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 2f6721d
- Refactor socket service handling

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - c9962fd
- Document qrexec-policy-agent API

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 51d1d09
- Add a test for no-GuiVM notifications

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 661e318
- qrexec-policy-daemon: don't reply with result=allow before execution

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 8467bb3
- Change format for 'ask' response

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 49e1240
- qrexec-policy-exec: handle 'execution failed' corner case

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 11835e1
- qrexec-policy-exec: recover from failure when notifying

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - c50a2e0
- Refactor socket server into a more reusable SocketService class

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 708334b
- Support notifications on allowed and denied calls

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - b4cf04c
- qrexec-policy-agent: add policy.Notify call

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 7711380
- Add missing license header

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 80c24a8
- travis: run pylint from docker

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - f17ae8a
- qrexec-policy-agent: enable systemd socket

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 4aac7b7
- qrexec-policy-agent: install in the common package, use socket activation

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 13d2735
- qrexec-policy-agent: prepare for GuiVM

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - df2cf67
- qrexec-policy-exec: don't use exit() directly in --just-ask

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - dccacea
- Rewrite CLI tests

* Fri Mar 27 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d304038
- rpm: add BR: systemd-devel to packages using %systemd_* macros

* Thu Mar 26 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f760688
- version 4.1.5

* Wed Mar 25 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - dcc4ae9
- Isolate *-base, *-dom0 and *-vm make targets

* Wed Mar 25 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5d01785
- daemon: fix makefile

* Wed Mar 25 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a23648b
- version 4.1.4

* Wed Mar 25 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - daf2a79
- Add a fuzzer for handle_remote_data

* Wed Mar 25 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 0e74722
- Add a fuzzer for parse_qubes_rpc_command

* Wed Mar 25 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 7c66fc9
- Factor out parse_qubes_rpc_command

* Tue Mar 24 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - e40196d
- daemon, agent: unify main loop

* Fri Mar 20 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - bd07c52
- Fix race condition in process_io

* Fri Mar 20 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 5dc2e4c
- Add an error message in case of early break

* Fri Mar 20 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 5938b66
- Handle POLLERR for stdin as well as POLLHUP

* Fri Mar 20 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 5312443
- process_io: use poll, detect socket close

* Fri Mar 20 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - efb794c
- Fix qrexec-fork-server handling of MSG_JUST_EXEC

* Thu Mar 19 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 857e753
- Update log messages

* Tue Mar 17 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - c469fb7
- Include program name in logs

* Tue Mar 17 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 65a60f7
- Fix "executed user pid" message

